'use strict'

var _interopRequireDefault = require('@babel/runtime/helpers/interopRequireDefault')

Object.defineProperty(exports, '__esModule', {
    value: true,
})
exports.uploadOrGetMetadata = exports.fileExists = exports.videoExists = exports.imageExists = exports.getMetadata = exports.uploadFile = exports.isVideo = void 0

var _regenerator = _interopRequireDefault(require('@babel/runtime/regenerator'))

var _asyncToGenerator2 = _interopRequireDefault(
    require('@babel/runtime/helpers/asyncToGenerator'),
)

var _promise = _interopRequireDefault(require('@babel/runtime/core-js/promise'))

var _cloudinary = _interopRequireDefault(require('cloudinary'))

var _urlExistsPromise = require('url-exists-promise')

var videoExtensions = ['mp4', 'webm']

var isVideo = function isVideo(path) {
    for (var i = 0; i < videoExtensions.length; i++) {
        var extension = videoExtensions[i]
        if (path.endsWith(extension)) return true
    }

    return false
}

exports.isVideo = isVideo

var uploadFile = function uploadFile(id, path) {
    return new _promise.default(function(resolve, reject) {
        return _cloudinary.default.v2.uploader.upload(
            path,
            {
                public_id: id,
                resource_type: isVideo(path) ? 'video' : 'image',
            },
            function(error, result) {
                if (error) reject(error)
                resolve(result)
            },
        )
    })
}

exports.uploadFile = uploadFile

var getMetadata = function getMetadata(id, path) {
    return new _promise.default(function(resolve, reject) {
        return _cloudinary.default.v2.uploader.explicit(
            id,
            {
                image_metadata: true,
                type: 'upload',
                resource_type: isVideo(path) ? 'video' : 'image',
            },
            function(error, result) {
                if (error) reject(error)
                resolve(result)
            },
        )
    })
}

exports.getMetadata = getMetadata

var imageExists = function imageExists(id, cloudName) {
    console.log(_cloudinary.default)
    var urlImg = 'http://res.cloudinary.com/'
        .concat(cloudName, '/image/upload/')
        .concat(id)
    return (0, _urlExistsPromise.urlExists)(urlImg)
}

exports.imageExists = imageExists

var videoExists = function videoExists(id, cloudName) {
    var urlVideo = 'http://res.cloudinary.com/'
        .concat(cloudName, '/video/upload/')
        .concat(id)
    return (0, _urlExistsPromise.urlExists)(urlVideo)
}

exports.videoExists = videoExists

var fileExists =
    /*#__PURE__*/
    (function() {
        var _ref = (0, _asyncToGenerator2.default)(
            /*#__PURE__*/
            _regenerator.default.mark(function _callee(id, path, cloudName) {
                return _regenerator.default.wrap(
                    function _callee$(_context) {
                        while (1) {
                            switch ((_context.prev = _context.next)) {
                                case 0:
                                    if (!isVideo(path)) {
                                        _context.next = 2
                                        break
                                    }

                                    return _context.abrupt(
                                        'return',
                                        videoExists(id, cloudName),
                                    )

                                case 2:
                                    return _context.abrupt(
                                        'return',
                                        imageExists(id, cloudName),
                                    )

                                case 3:
                                case 'end':
                                    return _context.stop()
                            }
                        }
                    },
                    _callee,
                    this,
                )
            }),
        )

        return function fileExists(_x, _x2, _x3) {
            return _ref.apply(this, arguments)
        }
    })()

exports.fileExists = fileExists

var uploadOrGetMetadata =
    /*#__PURE__*/
    (function() {
        var _ref2 = (0, _asyncToGenerator2.default)(
            /*#__PURE__*/
            _regenerator.default.mark(function _callee2(id, path, cloudName) {
                var exists
                return _regenerator.default.wrap(
                    function _callee2$(_context2) {
                        while (1) {
                            switch ((_context2.prev = _context2.next)) {
                                case 0:
                                    _context2.next = 2
                                    return fileExists(id, path, cloudName)

                                case 2:
                                    exists = _context2.sent

                                    if (exists) {
                                        _context2.next = 7
                                        break
                                    }

                                    return _context2.abrupt(
                                        'return',
                                        uploadFile(id, path),
                                    )

                                case 7:
                                    _context2.next = 9
                                    return getMetadata(id, path)

                                case 9:
                                    return _context2.abrupt(
                                        'return',
                                        _context2.sent,
                                    )

                                case 10:
                                case 'end':
                                    return _context2.stop()
                            }
                        }
                    },
                    _callee2,
                    this,
                )
            }),
        )

        return function uploadOrGetMetadata(_x4, _x5, _x6) {
            return _ref2.apply(this, arguments)
        }
    })()

exports.uploadOrGetMetadata = uploadOrGetMetadata
